# PyLORE

PACKAGE STILL IN DEVELOPMENT

## Installation

To install pylore run:

```bash
$ pip install pylore
```

## Usage

```python
from pylore.lore import LORE

LORE()
```

## Developing PyLORE

To install PyLORE, along with the tools you need to develop and run tests, run the following in your virtualenv:

```bash
$ pip install -e .[dev]
```
